@@ -6,7 +6,7 @@
 #              a PATH.
 # Author:      Sergio Talens-Oliag <sto@debian.org>
 # Copyright:   (c) 2006 Sergio Talens-Oliag <sto@debian.org>
-# SVN Id:      $Id: ssft.sh 79 2009-06-10 20:01:45Z sto $
+# SVN Id:      $Id: ssft.sh 86 2009-07-13 22:48:13Z sto $
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -157,7 +157,7 @@ When called directly the program supports the following options:
   ssft_sh_version() {
     ssft_set_textdomain
     _l_MSG="`eval_gettext \
-"Copyright (C) 2006 Sergio Talens-Oliag <sto@debian.org>
+"Copyright (C) 2006-2009 Sergio Talens-Oliag <sto@debian.org>
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."`"
     ssft_reset_textdomain
@@ -408,6 +408,56 @@ ssft_file_selection() {
   return $?
 }
 
+# Function: ssft_directory_selection TITLE
+#
+# Description: Read a path from the user and store the value on the
+# variable SSFT_RESULT. The function returns 0 if some value was set by the
+# user and != 0 if it wasn't.
+
+ssft_directory_selection() {
+  # MENU strings
+  ssft_set_textdomain
+  _l_FNAME_STR="`gettext "Directory"`"
+  ssft_reset_textdomain
+
+  # Local variables
+  _l_title="";
+  _l_fpath="";
+  
+  # Check arguments
+  if [ "$#" -lt 1 ]; then
+    return 255
+  fi
+  
+  # Set _l_variables
+  _l_title="$1";
+  
+  # Read values
+  case "$SSFT_FRONTEND" in
+  zenity)
+    _l_fpath=$( zenity --title "$_l_title" --file-selection --directory );
+  ;;
+  kdialog)
+    _l_fpath=$( kdialog --title "$_l_title" --getexistingdirectory "`pwd`" 2> /dev/null);
+  ;;
+  dialog)
+    _l_fpath=$( dialog --stdout --title "$_l_title" --dselect "`pwd`" 0 0 );
+  ;;
+  text)
+    ssft_print_text_title "$_l_title"
+    printf "%s: " "$_l_FNAME_STR"
+    read _l_fpath
+    echo ""
+  ;;
+  *)
+    _l_fpath=""
+  ;;
+  esac
+  SSFT_RESULT="$_l_fpath"
+  test -n "$_l_fpath"
+  return $?
+}
+
 # Function: ssft_progress_bar TITLE [TEXT [INITIAL_%]]
 #
 # Description: Show a progress bar to the user; the input contains two lines
@@ -1145,4 +1195,4 @@ ssft_show_file() {
 }
 
 # ------
-# SVN Id: $Id: ssft.sh 79 2009-06-10 20:01:45Z sto $
+# SVN Id: $Id: ssft.sh 86 2009-07-13 22:48:13Z sto $
